==> html2pdf-3.0.2-sources.jar: com/itextpdf/html2pdf/util/ReflectionUtils.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2020 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.html2pdf.util;

import com.itextpdf.html2pdf.Html2PdfProductInfo;
import com.itextpdf.kernel.Version;

import java.lang.reflect.Array;

/**
 * Utility class for handling operation related to reflections.
 */
public final class ReflectionUtils {

    private static final String LICENSEKEY_PACKAGE = "com.itextpdf.licensekey.";

    private static final String LICENSEKEY = "LicenseKey";
    private static final String LICENSEKEY_PRODUCT = "LicenseKeyProduct";
    private static final String LICENSEKEY_FEATURE = "LicenseKeyProductFeature";

    private static final String CHECK_LICENSEKEY_METHOD = "scheduledCheck";


    private ReflectionUtils() {
    }

    /**
     * Performs a scheduled license check.
     */
    public static void scheduledLicenseCheck() {
        try {
            Class licenseKeyProductClass = getClass(LICENSEKEY_PACKAGE + LICENSEKEY_PRODUCT);
            Object licenseKeyProductFeatureArray = Array.newInstance(
                    getClass(LICENSEKEY_PACKAGE + LICENSEKEY_FEATURE), 0);
            Class[] params = new Class[] {
                    String.class, Integer.TYPE,
                    Integer.TYPE, licenseKeyProductFeatureArray.getClass(),
            };
            Object licenseKeyProductObject = licenseKeyProductClass.getConstructor(params).newInstance(
                    Html2PdfProductInfo.PRODUCT_NAME, Html2PdfProductInfo.MAJOR_VERSION,
                    Html2PdfProductInfo.MINOR_VERSION, licenseKeyProductFeatureArray
            );
            getClass(LICENSEKEY_PACKAGE + LICENSEKEY).getMethod(CHECK_LICENSEKEY_METHOD, licenseKeyProductClass)
                    .invoke(null, licenseKeyProductObject);
        } catch (Exception e) {
            if (!Version.isAGPLVersion()) {
                throw new RuntimeException(e.getCause());
            }
        }
    }

    private static Class<?> getClass(String className) throws ClassNotFoundException {
        return Class.forName(className);
    }
}

==> html2pdf-3.0.3-sources.jar: com/itextpdf/html2pdf/util/ReflectionUtils.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2020 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.html2pdf.util;

import com.itextpdf.html2pdf.Html2PdfProductInfo;
import com.itextpdf.kernel.Version;

/**
 * Utility class for handling operation related to reflections.
 */
public final class ReflectionUtils {

    private static final String LICENSEKEY_PACKAGE = "com.itextpdf.licensekey.";

    private static final String LICENSEKEY = "LicenseKey";
    private static final String LICENSEKEY_PRODUCT = "LicenseKeyProduct";

    private static final String CHECK_LICENSEKEY_METHOD = "scheduledCheck";


    private ReflectionUtils() {
    }

    /**
     * Performs a scheduled license check.
     */
    public static void scheduledLicenseCheck() {
        try {
            Class licenseKeyProductClass = getClass(LICENSEKEY_PACKAGE + LICENSEKEY_PRODUCT);
            Class[] params = new Class[] {
                    String.class, String.class, String.class,
            };
            Object licenseKeyProductObject = licenseKeyProductClass.getConstructor(params).newInstance(
                    Html2PdfProductInfo.PRODUCT_NAME, String.valueOf(Html2PdfProductInfo.MAJOR_VERSION),
                    String.valueOf(Html2PdfProductInfo.MINOR_VERSION)
            );
            getClass(LICENSEKEY_PACKAGE + LICENSEKEY).getMethod(CHECK_LICENSEKEY_METHOD, licenseKeyProductClass)
                    .invoke(null, licenseKeyProductObject);
        } catch (Exception e) {
            if (!Version.isAGPLVersion()) {
                throw new RuntimeException(e.getCause());
            }
        }
    }

    private static Class<?> getClass(String className) throws ClassNotFoundException {
        return Class.forName(className);
    }
}
